@@ -32,7 +32,7 @@
 
 #include <rviz/display.h>
 
-#include <OGRE/OgreVector3.h>
+#include <rviz/ogre_helpers/ogre_vector.h>
 
 #include <map>
 
