@@ -68,7 +68,7 @@ Display::Display()
   // Make the display-enable checkbox show up, and make it unchecked by default.
   setValue(false);
 
-  connect(this, SIGNAL(changed()), this, SLOT(onEnableChanged()));
+  connect(this, &Property::changed, this, &Display::onEnableChanged);
 
   setDisableChildrenIfFalse(true);
 }
@@ -351,9 +351,9 @@ void Display::setAssociatedWidget(QWidget* widget)
 {
   if (associated_widget_panel_)
   {
-    disconnect(associated_widget_panel_, SIGNAL(visibilityChanged(bool)), this,
-               SLOT(associatedPanelVisibilityChange(bool)));
-    disconnect(associated_widget_panel_, SIGNAL(closed()), this, SLOT(disable()));
+    disconnect(associated_widget_panel_, &PanelDockWidget::visibilityChanged, this,
+               &Display::associatedPanelVisibilityChange);
+    disconnect(associated_widget_panel_, &PanelDockWidget::closed, this, &Display::disable);
   }
 
   associated_widget_ = widget;
@@ -363,9 +363,9 @@ void Display::setAssociatedWidget(QWidget* widget)
     if (wm)
     {
       associated_widget_panel_ = wm->addPane(getName(), associated_widget_);
-      connect(associated_widget_panel_, SIGNAL(visibilityChanged(bool)), this,
-              SLOT(associatedPanelVisibilityChange(bool)));
-      connect(associated_widget_panel_, SIGNAL(closed()), this, SLOT(disable()));
+      connect(associated_widget_panel_, &PanelDockWidget::visibilityChanged, this,
+              &Display::associatedPanelVisibilityChange);
+      connect(associated_widget_panel_, &PanelDockWidget::closed, this, &Display::disable);
       associated_widget_panel_->setIcon(getIcon());
     }
     else
