@@ -225,7 +225,7 @@ public:
 
 Q_SIGNALS:
 
-  void timeSignal(rviz::Display* display, ros::Time time);
+  void timeSignal(ros::Time time, QPrivateSignal);
 
 public Q_SLOTS:
   /** @brief Enable or disable this Display.
@@ -328,7 +328,7 @@ private:
   uint32_t visibility_bits_;
   QWidget* associated_widget_;
   PanelDockWidget* associated_widget_panel_;
-  bool associated_widget_visible_;
+  bool suppress_hiding_associated_widget_panel_;
 };
 
 } // end namespace rviz
