@@ -33,7 +33,7 @@
 #include <rviz/ogre_helpers/version_check.h>
 #include <OgreSceneManager.h>
 #include <OgreSceneNode.h>
-#include <OgreVector3.h>
+#include <rviz/ogre_helpers/ogre_vector.h>
 #include <OgreQuaternion.h>
 #include <OgreEntity.h>
 #include <OgreMaterialManager.h>
